# `cupid_streamlit` module

An interactive Streamlit application that solves for the stable matching and estimates the parameters of the joint surplus in a [Choo and Siow 2006](https://www.jstor.org/stable/10.1086/498585?seq=1) homoskedastic model.

::: cupid_matching.cupid_streamlit
